Use and citations
=================

Citation
--------

If you make use of this code in your work, please cite::

    @misc{Cheong2022diffoptics,
        author={Cheong Sanha, Sean Gasiorowski, Kagan Michael, Safdari Murtaza, Schwartzman Ariel, Vandegar Maxime},
        title={GradOptics: Differentiable Optics via Ray Tracing},
        url={https://magis-slac.github.io/gradoptics}
        year={2022},
    }

Use in Publications
-------------------

::

    @article{Cheong_2022,
             year = 2022,
             publisher = {{IOP} Publishing},
             volume = {17},
             number = {08},
             pages = {P08021},
             author = {S. Cheong and J.C. Frisch and S. Gasiorowski and J.M. Hogan and M. Kagan and M. Safdari and A. Schwartzman and M. Vandegar},
             title = {Novel light field imaging device with enhanced light collection for cold atom clouds},
             journal = {Journal of Instrumentation},
    }